# Installation

To install the latest release:

```python
pip install valency-anndata
```

At the moment, there are a lot of core dependencies (even without installing development packages). In the future, we will have a more slim core if there is interest.

To install unreleased code from the source repository:

```py
pip install git+https://github.com/patcon/valency-anndata
```